<?php

declare(strict_types=1);

namespace Dedi\SyliusVoucherPlugin\Controller\Action;

use Dedi\SyliusVoucherPlugin\Form\Type\VoucherSearchType;
use FOS\RestBundle\View\View;
use FOS\RestBundle\View\ViewHandlerInterface;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

final class SearchVoucherAction
{
    /** @var ViewHandlerInterface */
    private $viewHandler;

    /** @var FormFactoryInterface */
    private $formFactory;

    public function __construct(
        ViewHandlerInterface $viewHandler,
        FormFactoryInterface $formFactory
    ) {
        $this->viewHandler = $viewHandler;
        $this->formFactory = $formFactory;
    }

    public function __invoke(Request $request): Response
    {
        $searchVoucherCommand = new SearchVoucherCommand();
        $form = $this->formFactory->create(VoucherSearchType::class, $searchVoucherCommand);
        $form->handleRequest($request);

        $view = View::create();
        $view
            ->setTemplate('@DediSyliusVoucherPlugin/Shop/Voucher/search.html.twig')
            ->setData([
                'form' => $form->createView(),
                'voucher' => ($form->isSubmitted() && $form->isValid()) ? $searchVoucherCommand->getVoucher() : null,
            ])
        ;

        return $this->viewHandler->handle($view);
    }
}
